@@ -127,7 +127,7 @@ class SubscribeContent(BoxLayout):
         ]
         self.menu = MDDropdownMenu(
             caller=self.ids.drop_item,
-            background_color=get_color_from_hex("#0d021b"),
+            background_color=get_color_from_hex("#1212"),
             items=menu_items,
             position="center",
             width_mult=4,
@@ -227,7 +227,7 @@ class RecycleViewRow(MDCard,RectangularElevationBehavior,ThemableBehavior, Hover
         Window.set_system_cursor('hand')
         
     def on_leave(self, *args):
-        self.md_bg_color = get_color_from_hex("#0d021b")
+        self.md_bg_color = get_color_from_hex("#1212")
         Window.set_system_cursor('arrow')
         
     def get_city_of_node(self, naddress):   
@@ -258,7 +258,7 @@ class RecycleViewRow(MDCard,RectangularElevationBehavior,ThemableBehavior, Hover
 
         if not self.dialog:
             self.dialog = MDDialog(
-                md_bg_color=get_color_from_hex("#0d021b"),
+                md_bg_color=get_color_from_hex("#1212"),
                 text='''
 City: %s
 Connected Peers:  %s  
@@ -284,7 +284,7 @@ Node Version: %s
                     title="Node:",
                     type="custom",
                     content_cls=subscribe_dialog,
-                    md_bg_color=get_color_from_hex("#0d021b"),
+                    md_bg_color=get_color_from_hex("#1212"),
                     buttons=[
                         MDFlatButton(
                             text="CANCEL",
@@ -313,7 +313,7 @@ Node Version: %s
                 title="Subscribing...",
                 type="custom",
                 content_cls=spdialog,
-                md_bg_color=get_color_from_hex("#0d021b"),
+                md_bg_color=get_color_from_hex("#1212"),
             )
         self.dialog.open()
         yield 0.6
@@ -327,7 +327,7 @@ Node Version: %s
             self.dialog.dismiss()
             self.dialog = MDDialog(
                 title="Successful!",
-                md_bg_color=get_color_from_hex("#0d021b"),
+                md_bg_color=get_color_from_hex("#1212"),
                 buttons=[
                         MDFlatButton(
                             text="OK",
@@ -341,7 +341,7 @@ Node Version: %s
             self.dialog.dismiss()
             self.dialog = MDDialog(
             title="Error: %s" % "No wallet found!" if returncode[1] == 1337  else returncode[1],
-            md_bg_color=get_color_from_hex("#0d021b"),
+            md_bg_color=get_color_from_hex("#1212"),
             buttons=[
                     MDFlatButton(
                         text="OK",
@@ -451,23 +451,10 @@ class RecycleViewSubRow(MDCard,RectangularElevationBehavior):
             consumed = float(float(re.findall(r'[0-9]+\.[0-9]+', consumed)[0].replace('B', '')) / (1024*1024*1024))
         
         return consumed
-        
-    def connected_quota(self, allocated, consumed):        
-        if Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).CONNECTED:
-            allocated = float(allocated.replace('GB',''))
-            consumed  = self.compute_consumed_data(consumed)
-            Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).ids.quota_pct.text = str(round(float(float(consumed/allocated)*100),2)) + "%"
-            return round(float(float(consumed/allocated)*100),3)
-        else:
-            Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).ids.quota_pct.text = "0.00%"
-            Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).ids.quota.value    = 0
-            return float(0)
-            
-    
     
     def add_loading_popup(self, title_text):
         self.dialog = None
-        self.dialog = MDDialog(title=title_text,md_bg_color=get_color_from_hex("#0d021b"))
+        self.dialog = MDDialog(title=title_text,md_bg_color=get_color_from_hex("#1212"))
         self.dialog.open()
         
     def remove_loading_widget(self):
@@ -531,7 +518,8 @@ class RecycleViewSubRow(MDCard,RectangularElevationBehavior):
                 Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).NodeSwitch['id']        = ID
                 Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).NodeSwitch['allocated'] = self.allocated_text
                 Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).NodeSwitch['consumed']  = self.consumed_text
-                Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).NodeSwitch['og_consumed']  = deepcopy(Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).NodeSwitch['consumed']) 
+                #Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).NodeSwitch['og_consumed']  = deepcopy(Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).NodeSwitch['consumed']) 
+                Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).NodeSwitch['og_consumed']  = deepcopy(self.consumed_text) 
                 
                 if not ID in Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).PersistentBandwidth:
                     Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).PersistentBandwidth[ID] = Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).NodeSwitch
@@ -544,7 +532,7 @@ class RecycleViewSubRow(MDCard,RectangularElevationBehavior):
                 self.remove_loading_widget()
                 self.dialog = MDDialog(
                     title="Connected!",
-                    md_bg_color=get_color_from_hex("#0d021b"),
+                    md_bg_color=get_color_from_hex("#1212"),
                     buttons=[
                             MDFlatButton(
                                 text="OK",
@@ -558,7 +546,7 @@ class RecycleViewSubRow(MDCard,RectangularElevationBehavior):
                 self.remove_loading_widget()
                 self.dialog = MDDialog(
                     title="Something went wrong. Not connected",
-                    md_bg_color=get_color_from_hex("#0d021b"),
+                    md_bg_color=get_color_from_hex("#1212"),
                     buttons=[
                             MDFlatButton(
                                 text="OK",
@@ -567,24 +555,42 @@ class RecycleViewSubRow(MDCard,RectangularElevationBehavior):
                                 on_release=partial(self.call_ip_get, False, "")
                             ),])
                 self.dialog.open()
-    
+    def connected_quota(self, allocated, consumed):        
+        if Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).CONNECTED:
+            #allocated = float(allocated.replace('GB',''))
+            allocated = self.compute_consumed_data(allocated)
+            consumed  = self.compute_consumed_data(consumed)
+            Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).ids.quota_pct.text = str(round(float(float(consumed/allocated)*100),2)) + "%"
+            return round(float(float(consumed/allocated)*100),3)
+        else:
+            Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).ids.quota_pct.text = "0.00%"
+            Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).ids.quota.value    = 0
+            return float(0)
+        
+            
     def setQuotaClock(self,ID, naddress):
+        
+        BytesDict = self.init_GetConsumedWhileConnected(Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).PersistentBandwidth[ID]['og_consumed'])
+        print(BytesDict)
         self.UpdateQuotaForNode(Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).NodeSwitch['id'],
                                 Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).NodeSwitch['node'],
+                                BytesDict,
                                 None)
+        
         Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).clock = Clock.create_trigger(partial(self.UpdateQuotaForNode,
                                                   Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).NodeSwitch['id'],
-                                                  Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).NodeSwitch['node']),
-                                                  120)
+                                                  Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).NodeSwitch['node'],
+                                                  BytesDict),120)
+
         Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).clock()
         
-    def UpdateQuotaForNode(self, ID, naddress, dt):
+    def UpdateQuotaForNode(self, ID, naddress, BytesDict, dt):
         try:
             print("%s: Getting Quota: " % ID, end= ' ')
             startConsumption = Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).PersistentBandwidth[ID]['og_consumed']
-            Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).PersistentBandwidth[ID]['consumed'] = self.GetConsumedWhileConnected(self.compute_consumed_data(startConsumption))
+            Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).PersistentBandwidth[ID]['consumed'] = self.GetConsumedWhileConnected(self.compute_consumed_data(startConsumption),BytesDict)
             
-            Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).ids.quota.value = self.connected_quota(Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).NodeSwitch['allocated'],
+            Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).ids.quota.value = self.connected_quota(Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).PersistentBandwidth[ID]['allocated'],
                                                                                                       Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).PersistentBandwidth[ID]['consumed'])
             print("%s,%s - %s%%" % (Meile.app.root.get_screen(WindowNames.MAIN_WINDOW).PersistentBandwidth[ID]['consumed'],
                                   startConsumption,
@@ -599,13 +605,21 @@ class RecycleViewSubRow(MDCard,RectangularElevationBehavior):
             print("Error running clock()")
             print(str(e))
             pass 
+    def init_GetConsumedWhileConnected(self, sConsumed):
+        try: 
+            bytes_sent = round(float(float(psutil.net_io_counters(pernic=True)['wg99'].bytes_sent) / 1073741824),3)
+            bytes_recvd = round(float(float(psutil.net_io_counters(pernic=True)['wg99'].bytes_recv) / 1073741824),3)
+            
+            return {'sent' : bytes_sent, "rcvd" : bytes_recvd}
+        except:
+            return {'sent': 0, 'rcvd' : 0}
         
-    def GetConsumedWhileConnected(self, sConsumed):
-        bytes_sent = round(float(float(psutil.net_io_counters(pernic=True)['wg99'].bytes_sent) / 1073741824),3)
-        bytes_recvd = round(float(float(psutil.net_io_counters(pernic=True)['wg99'].bytes_recv) / 1073741824),3)
+    def GetConsumedWhileConnected(self, sConsumed, Bytes):
+        bytes_sent = round(float(float(float(psutil.net_io_counters(pernic=True)['wg99'].bytes_sent) / 1073741824) - Bytes['sent']),3) 
+        bytes_recvd = round(float(float(float(psutil.net_io_counters(pernic=True)['wg99'].bytes_recv) / 1073741824) - Bytes['rcvd']),3)  
         
         total_data = str(round(float(bytes_sent + bytes_recvd)+ float(sConsumed),3)) + "GB"
-        
+        print("Total Data: %s" % total_data, end=' ')
         return total_data    
                 
     def call_ip_get(self,result, moniker,  *kwargs):
@@ -663,6 +677,6 @@ class MDMapCountryButton(MDFillRoundFlatButton,ThemableBehavior, HoverBehavior):
         '''The method will be called when the mouse cursor goes beyond
         the borders of the current widget.'''
 
-        self.md_bg_color = get_color_from_hex("#0d021b")
+        self.md_bg_color = get_color_from_hex("#1212")
         Window.set_system_cursor('arrow')
             
\ No newline at end of file
